<template>
  <el-dialog
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
    append-to-body
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      @keyup.enter.native="dataFormSubmit()"
      label-width="80px"
      class="l-mes"
    >
      <el-row>
        <el-col :span="12">
          <el-form-item label="零件" prop="partId">
            <el-input v-model="partStr" placeholder="" readonly>
              <el-button
                slot="append"
                icon="el-icon-search"
                @click="openPartDialog()"
              ></el-button>
            </el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="库位" prop="locationId">
            <el-select
              v-model="dataForm.locationId"
              filterable
              placeholder=""
              style="width:100%"
            >
              <el-option
                v-for="item in this.locations"
                :key="item.id"
                :label="item.locName + '----' + item.locNo"
                :value="item.id"
              >
              </el-option>
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="零件批号" prop="partBatchNo">
            <el-input v-model="dataForm.partBatchNo" placeholder=""></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="接收数量" prop="receiveQty">
            <el-input v-model="dataForm.receiveQty" placeholder=""></el-input>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button type="primary" @click="dataFormSubmit()">确定</el-button>
    </span>

    <part-dialog
      :currshowlist.sync="showPart"
      @listenToPartEvent="selectPart"
    />
  </el-dialog>
</template>

<script>
import {
  getReceivingDetail,
  addReceivingDetail,
  putReceivingDetail
} from '@/api/warehouse/receiving'
import { loadLocation } from '@/api/warehouse/location'
import PartDialog from '@/views/common/part'
import { validateSixDecimalNotNull } from '@/util/validate'

export default {
  components: {
    PartDialog
  },
  data() {
    return {
      locations: [],
      visible: false,
      factory: null,
      dataForm: {
        id: 0,
        receivingMainId: '',
        partId: '',
        partName: '',
        partNo: '',
        locationId: '',
        partBatchNo: '',
        receiveQty: ''
      },
      dataRule: {
        partId: [{ required: true, message: '零件不能为空', trigger: 'blur' }],
        locationId: [
          { required: true, message: '库位不能为空', trigger: 'blur' }
        ],
        receiveQty: [
          { required: true, message: '接收数量不能为空', trigger: 'blur' },
          { validator: validateSixDecimalNotNull, trigger: 'blur' }
        ]
      },
      showPart: false
    }
  },
  computed: {
    partStr: function() {
      return this.dataForm.partId
        ? this.dataForm.partName +
            '  ' +
            (this.dataForm.partNo ? this.dataForm.partNo : '')
        : ''
    }
  },
  methods: {
    init(id, receivingMainId, factoryId) {
      this.dataForm.receivingMainId = receivingMainId
      this.dataForm.id = id || 0
      this.factory = factoryId
      this.visible = true
      this.$nextTick(() => {
        this.initLocationSelect()
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getReceivingDetail(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
          })
        }
      })
    },
    // 表单提交
    dataFormSubmit() {
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          if (this.dataForm.id) {
            putReceivingDetail(this.dataForm).then((data) => {
              this.$message.success('修改成功')
              this.visible = false
              this.$emit('refreshDataList')
            })
          } else {
            addReceivingDetail(this.dataForm).then((data) => {
              this.$message.success('添加成功')
              this.visible = false
              this.$emit('refreshDataList')
            })
          }
        }
      })
    },
    // 零件选择
    openPartDialog() {
      this.showPart = true
    },
    selectPart(part) {
      if (part) {
        this.dataForm.partNo = part.partNo
        this.dataForm.partName = part.partName
        this.dataForm.partId = part.id
        this.$refs.dataForm.validateField('partId', (valid) => {})
      }
    },
    // 获取库位的数据
    initLocationSelect() {
      loadLocation(
        Object.assign({
          factoryId: this.factory
        })
      ).then((res) => {
        this.locations = res.data.data
      })
    }
  }
}
</script>
